@@ -819,6 +819,16 @@ class BaseController extends ActionController {
             }
             $this->filter->setAufzug(is_numeric($filterValues['aufzug']) ? intval($filterValues['aufzug']) : null);
             $this->filter->setBarrierefrei(is_numeric($filterValues['barrierefrei']) ? intval($filterValues['barrierefrei']) : null);
+
+            if (isset($filterValues['latitude']) && isset($filterValues['longitude']) && is_numeric($filterValues['latitude']) && is_numeric($filterValues['longitude']) && $filterValues['latitude'] != 0 && $filterValues['longitude'] != 0){
+                $this->filter->setLatitude($filterValues['latitude']);
+                $this->filter->setLongitude($filterValues['longitude']);
+                if (isset($filterValues['radius']) && is_numeric($filterValues['radius']) && $filterValues['radius'] > 0){
+                    $this->filter->setRadius($filterValues['radius']);
+                }else{
+                    $this->filter->setRadius($this->settings['preset']['search']['radius']);
+                }
+            }
         }else{
             // No Data for Filter in Request
             $filter = $this->sessionHandler->restoreFromSession('filter');
